@@ -1,9 +1,10 @@
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "gd.h"
 #include "gdhelpers.h"
 #include <stdlib.h>
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 #include <string.h>
 
 /* TBB: gd_strtok_r is not portable; provide an implementation */
@@ -92,8 +93,7 @@ gdRealloc (void *ptr, size_t size)
   return realloc (ptr, size);
 }
 
-void
-gdFree (void *ptr)
+BGD_DECLARE(void) gdFree (void *ptr)
 {
   free (ptr);
 }
